aboutsummaryrefslogtreecommitdiff
path: root/include/llvm/Target/TargetJITInfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/Target/TargetJITInfo.h')
-rw-r--r--include/llvm/Target/TargetJITInfo.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/llvm/Target/TargetJITInfo.h b/include/llvm/Target/TargetJITInfo.h
index 45aae06e3f..0ae24169b8 100644
--- a/include/llvm/Target/TargetJITInfo.h
+++ b/include/llvm/Target/TargetJITInfo.h
@@ -40,12 +40,12 @@ namespace llvm {
///
virtual void replaceMachineCodeForFunction(void *Old, void *New) = 0;
- /// emitGlobalValueNonLazyPtr - Use the specified MachineCodeEmitter object
- /// to emit a Mac OS X non-lazy pointer which contains the address of the
- /// specified ptr.
- virtual void *emitGlobalValueNonLazyPtr(const GlobalValue* GV, void *ptr,
- MachineCodeEmitter &MCE) {
- assert(0 && "This target doesn't implement emitGlobalValueNonLazyPtr!");
+ /// emitGlobalValueIndirectSym - Use the specified MachineCodeEmitter object
+ /// to emit an indirect symbol which contains the address of the specified
+ /// ptr.
+ virtual void *emitGlobalValueIndirectSym(const GlobalValue* GV, void *ptr,
+ MachineCodeEmitter &MCE) {
+ assert(0 && "This target doesn't implement emitGlobalValueIndirectSym!");
return 0;
}